#!/bin/sh 

# Copyright (C) 2002 Michael Fratoni
# <Devon@tuxfan.homeip.net>
# Copyright (C) The "RULE" project
# http://www.freesoftware.fsf.org/rule

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# The GNU General Public License is also available online:
# http://www.gnu.org/licenses/gpl.html

#############################################################################

# set -x

rs=/root/scripts
rsv=/root/scripts/${version}
i_log="$rs/install.log"

# Read the list of packages to install.
# Do the installation.

/root/scripts/mount_installsource.sh

# Language selection
# If not defined, ask.
if [ -z ${LANGS} ]; then
    cat<<EOF 
    By default, all included locale files are installed.
    This can use a lot of additional disk space. You may
    install only specific language files, if desired.

    If you choose to install only a small subset of languages,
    it will be difficult to later add a new language. When
    prompted, you may enter a colin(:) separated list of _VALID_
    language abbreviations, or <enter> to ignore this option. 

    For example, entering 'en:fr:de:it' (without quotes)
    Would install support for English, French, German, and Italian.

    Please make sure that you enter only valid abbreviations!
    A list of allowable values is:
    af:sq:ar:eu:be:bs:br:ca:zh:kw:hr:cs:da:nl:en:et:fo:fi:fr:gl:de
    el:kl:he:hi:hu:is:id:ga:it:ja:ko:lv:lt:mk:ms:mt:gv:mr:se:no:nn
    oc:fa:pl:pt:ro:ru:sr:sk:sl:es:sv:tl:ta:te:th:tr:uk:ur:uz:wa
    
    If you are unsure, hit <enter> to default to 'all'.
    
EOF
    
    echo -n "Language selection? [ <enter> to ignore ]: "
    read LANGS
    if [ -n "${LANGS}" ]; then
        echo "%_install_langs     ${LANGS}" > /etc/rpm/macros
        echo "rpm is configured to install the following locales:" | tee -a $i_log
        echo "${LANGS}" | tee -a $i_log
        echo "This is configured via /etc/rpm/macros"
    else
        echo "Defaulting to installing all locale files." | tee -a $i_log
    fi
    echo
fi

# Package selection
# Base packages always selected
install_list="base_packages.disc1"

# This changed in 0.5.05:
# The following part of selecting preconfigured packages is obsolet
# but still present to see what could be.
# Slinky now can only install the base-set of packages from disc1
# or all packages from all discs.
# If  you want a customized system install the base-packages and
# add any other software later using rmp or yum

# Add extra_packages
# install_list="$install_list extra_packages.disc1"

# if not defined, ask:
if [ -z ${use_package_set} ]; then

# Package selection
    echo "Packages for a base system are preselected. Please"
    echo "Select additional package groups in the dialog below."
    echo "If you have included a file containing a list of"
    echo "rpms and named it extra_packages, those will be"
    echo "installed as well."
    echo

    answer=
    echo -n "Install packages for laptop support? [ yes / NO ]: "
    read answer
    if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
        echo "Laptop packages selected for install." | tee -a $i_log
        LAPTOP=1
    fi
    
    answer=
    echo -n "Install packages for network support? [ yes / NO ]: "
    read answer
    if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
        echo "Network packages selected for install." | tee -a $i_log
        NETWORK=1
    else
        NETWORK=0
    fi
    
    answer=
    echo -n "Install packages for dialup support? [ yes / NO ]: "
    read answer
    if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
        echo "Dialup packages selected for install." | tee -a $i_log
        DIALUP=1
    fi
    
    answer=
    echo -n "Install packages for dhcp client support? [ yes / NO ]: "
    read answer
    if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
        echo "DHCP packages selected for install." | tee -a $i_log
        DHCP=1
    fi

    answer=
    echo -n "Install web tools and communication packages? [ yes / NO ]: "
    read answer
    if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
        echo "web tools packages selected for install." | tee -a $i_log
        WEBTOOLS=1
    fi

    answer=
    echo -n "Install openssh/sh server? [ yes / NO ]: "
    read answer
    if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
        echo "Openssh  packages selected for install." | tee -a $i_log
        OPENSSH=1
    fi

    # TinyX and Fluxbox for version 9 only at present!
    if [ "$version" -eq "9" ]; then
        answer=
        echo -n "Install TinyX and small window managers? [ yes / NO ]: "
        read answer
        if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
            echo "TinyX packages selected for install." | tee -a $i_log
            TINYX=1
        fi
    fi

    if [ "$TINYX" -ne "1" ]; then
        answer=
        echo -n "Install basic XFree86 packages? [ yes / NO ]: "
        read answer
        if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
            echo "XFree86 packages selected for install." | tee -a $i_log
            XFREE86=1
        else
            XFREE86=0
        fi
    fi

    # If XFree86 wasn't selected, no sense asking about the desktop packages.
    if [ "$XFREE86" -eq "1" ]; then
        answer=
        echo -n "Install KDE Desktop packages? [ yes / NO ]: "
        read answer
        if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
            echo "KDE packages selected for install." | tee -a $i_log
            KDE=1
        fi

        answer=
        echo -n "Install Gnome Desktop packages? [ yes / NO ]: "
        read answer
        if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
            echo "Gnome desktop packages selected for install." | tee -a $i_log
            GNOME=1
        fi
    fi

    answer=
    echo -n "Install sendmail server? [ yes / NO ]: "
    read answer
    if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
        echo "Sendmail packages selected for install." | tee -a $i_log
        SENDMAIL=1
    fi

    if [ "$version" -eq "9" ]; then
        if [ "$XFREE86" -eq "1" ] || [ "$TINYX" -eq "1" ]; then
            answer=
            echo -n "Install AbiWord (word processor) packages? [ yes / NO ]: "
            read answer
            if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
                echo "AbiWord packages selected for install." | tee -a $i_log
                ABIWORD=1
            fi
            echo -n "Install Mozilla (web browser) packages? [ yes / NO ]: "
            read answer
            if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
                echo "Mozilla packages selected for install." | tee -a $i_log
                MOZILLA=1
            fi
            echo -n "Install Open Office (office suite) packages? [ yes / NO ]: "
            read answer
            if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
                echo "OpenOffice packages selected for install." | tee -a $i_log
                OPENOFFICE=1
            fi
            echo -n "Install printing support (cups) packages? [ yes / NO ]: "
            read answer
            if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
                echo "Printing packages selected for install." | tee -a $i_log
                PRINTING=1
            fi
            echo -n "Install date/time configuration packages? [ yes / NO ]: "
            read answer
            if [ "$answer" = "yes" ] || [ "$answer" = "y" ]; then
                echo "Dateconfig packages selected for install." | tee -a $i_log
                DATECONFIG=1
            fi
        fi
    fi
fi

# These should have been defined above, or from the config file.

if [ "$LAPTOP" = '1' ]; then
    install_list="$install_list laptop_packages.disc1"
fi

if [ "$DIALUP" = '1' ]; then
    install_list="$install_list dialup_packages.disc1"
    NETWORK=1
fi

if [ "$DHCP" = '1' ]; then
    install_list="$install_list dhcp_packages.disc1"
    NETWORK=1
fi

if [ "$WEBTOOLS" = '1' ]; then
    install_list="$install_list webtools_packages.disc1"
    NETWORK=1
    SENDMAIL=1
fi

if [ "$OPENSSH" = '1' ]; then
    install_list="$install_list openssh_packages.disc1"
    NETWORK=1
fi

if [ "$KDE" = '1' ]; then
    install_list="$install_list KDE_packages.disc1"
    NETWORK=1
    XFREE86=1
fi

if [ "$GNOME" = '1' ]; then
    install_list="$install_list Gnome_packages.disc1"
    XFREE86=1
    NETWORK=1
fi

if [ "$SENDMAIL" = '1' ]; then
    install_list="$install_list mailserver_packages.disc1"
    NETWORK=1
fi

if [ "$NETWORK" = '1' ]; then
    install_list="$install_list network_packages.disc1"
fi

if [ "$XFREE86" = '1' ] || [ "$TINYX" = '1' ]; then
    install_list="$install_list XF86_packages.disc1"
fi

if [ "$ABIWORD" = '1' ]; then
    install_list="$install_list abiword_packages.disc1"
fi

if [ "$MOZILLA" = '1' ]; then
    install_list="$install_list mozilla_packages.disc1"
fi

if [ "$OPENOFFICE" = '1' ]; then
    install_list="$install_list openoffice_packages.disc1"
fi

if [ "$PRINTING" = '1' ]; then
    install_list="$install_list printing_packages.disc1"
fi

if [ "$DATECONFIG" = '1' ]; then
    install_list="$install_list dateconfig_packages.disc1"
fi

export install_list

RPM_PATH="/mnt/cdrom/${distri}/RPMS/"

case $method in
'cdrom'|'iso'|'rpms'|'nfsiso'|'nfsrpms')
    # RPM_COMMAND="/bin/rpm -ivh --force ${RPM_PATH}"
    # RPM_INFO="/bin/rpm -qi -p ${RPM_PATH}"
    set +x
    ;;
'httprpms')
    mkdir /httptmp
    ;;
'ftprpms')
    mkdir /ftptmp

    # set the ftpget-options
    useropt="-u `echo $LOGIN | cut -d: -f1`"
    passopt="-p `echo $LOGIN | cut -d: -f2`"
    [ "$useropt" = '-u ' ] && useropt=''
    [ "$passopt" = '-p ' ] && passopt=''
    [ -n "$DELIM" ] && delim=':' || delim=''
    hostopt="$HOST$delim$PORT"
    pathopt="$FILE_PATH"

    # RPM_COMMAND="/bin/rpm -ivh --force ftp://${LOGIN}@${HOST}${PORT}${FILE_PATH}"
    ;;
esac

# Hack:
# rpm complains about missing directories and files, so provide them.
# For some reason, they are not automatically created with rpm
mkdir -p /var/lib/rpm
mkdir -p /var/lock/rpm
mkdir -p /etc/security/selinux

> /etc/security/selinux/file_contexts
mkdir -p /usr/share/info

# rpm will create a bunch of .rpmsave and .rpmnew files if files already exist

rm -f /etc/default/nss /etc/localtime /etc/nsswitch.conf /etc/rpc
rm -f /usr/lib/gconv/gconv-modules /etc/termcap /etc/skel/.bash*
rm -f /etc/cron.daily/rpm /etc/logrotate.d/rpm /etc/aliases /etc/bashrc
rm -f /etc/csh.cshrc /etc/csh.login /etc/environment /etc/exports /etc/filesystems
rm -f /etc/group /etc/host.conf /etc/hosts.allow /etc/hosts.deny /etc/inputrc
rm -f /etc/motd /etc/passwd /etc/printcap /etc/profile /etc/protocols
rm -f /etc/securetty /etc/services /etc/shells /var/log/lastlog /etc/default/useradd
rm -f /etc/login.defs
rm -rf /usr/lib/locale/*

# needed for scrollkeeper (?)
mkdir -p /etc/xml

# echo "In FC3 if we don't set LD_ASSUME_KERNEL=2.4.1 rpm will hang sooner or later"
[ "$version" = '3' ] && export LD_ASSUME_KERNEL=2.4.1

echo "Initialize rpm-Database"
/bin/rpm --initdb

echo "Installing Fedora Core ${version} RPM-GPG-KEYs"
for k in $rsv/RPM-GPG-KEY*; do
  /bin/rpm --import $k
done

# list available package groups that can be installed
# 2nd word is the default setting
cat >$rs/package_list.raw <<EOF
base on
EOF

# older package-lists
# network off
# dhcp off
# laptop off
# dialup off
# webtools off
# openssh off
# xorg off
# sendmail off
# printing off
# EOF

# prefix linenumber
busybox awk '{print ++i " " $1 " " $2}' $rs/package_list.raw >$rs/package_list.txt

echo 1 >/tmp/dialog.ipt # first package 'base' is always installed

dialog --no-collapse --msgbox "
    We are going to install a base-set of FC${version} packages.

    You can install other packages later using rpm or yum.

    If the screen should 'blank' due to inactivity, DO NOT hit
    the <ENTER> key. Please use the <SHIFT>-key instead.
" 12 70

for d in 1 2 3 4 5; do
    [ -f $rsv/base_packages.disc$d ] && { 
        echo installing rpm-packages listed in $rsv/base_packages.disc$d ============= >>$i_log
        cat $rsv/base_packages.disc$d >>$i_log
        cat $rsv/base_packages.disc$d >>$rsv/install.disc$d 
    }
done

while :; do
    dialog --yesno "
    Packages are suited to install software and documentation.
    If you want to save diskspace you can skip docs.

    Do you want to skip installation of documentation?
" 10 70
    [ $? -eq 0 ] && answer=yes || answer=no
    case "$answer" in
    'yes')
        skipdocs=--excludedocs
        break
        ;;
    'no')
        skipdocs=
        break
        ;;
    *)
        echo
        echo "Your answer was <$answer>.  Try again."
        echo
        continue
        ;;
    esac
done

> /etc/ld.so.conf

# remove some relicts from the rpm-bootstrap in order to avoid warnings
rm -f /etc/pcmcia/config /etc/krb5.conf /etc/issue /etc/issue.net \
    /etc/sysconfig/rhn/sources /etc/pwdb.conf /etc/fdprm /etc/syslog.conf \
    /etc/scsi_id.config /sbin/installkernel /etc/X11/prefdm /etc/adjtime \
    /etc/initlog.conf /etc/inittab /sbin/ifdown /sbin/ifup /etc/lvm/lvm.conf

rm -rf /usr/share/hwdata /etc/pki/tls /etc/makedev.d /etc/yum.repos.d \
    /etc/iproute2 /etc/rc.d /etc/netplug /etc/pam.d /etc/security \
    /etc/pam.d /etc/logrotate.d /etc/hotplug.d /etc/ppp /etc/profile.d \
    /etc/sysconfig

# Install all requested packages from one disc in one rpm-call
# let rpm decide order of installation, dependency-check not disabled.
#
# This strategy only works if there are only dependencies from packages from
# discX to discY, where Y<=X. But sometimes a rmp from disc1 depends on another
# one from disc2.  So we better use option --nodeps
#

for disc in disc1; do
    if [ "$disc" != 'disc1' ]; then
        package_ct=`sort -u $rsv/install.$disc | grep -v '^--' | wc -l`
        if [ "$package_ct" -le 0 ]; then
            echo package $disc $package_ct war 0 ===
            read x
            continue
        fi

        # first mount installation source
        case "$method" in
	'cdrom')
	    umount /mnt/cdrom
            eject $CDROM_DEV
            echo Please insert ${distri} Core ${version} ${disc} and hit ENTER, Skip with NO
            read ans
            if [ "$ans" != 'NO' ]; then
                # echo "Please insert ${distri} Core ${version} ${disc} in your cd drive."
                # echo "Press ENTER when ready."
                # read answer
                echo "Mounting $CDROM_DEV on /mnt/cdrom"
                mount -t iso9660 $CDROM_DEV /mnt/cdrom > /dev/null 2>&1 || {
                    echo
                    echo "Mount failed, switch to another console and try mounting manually:"
                    echo "mount -t iso9660 $CDROM_DEV /mnt/cdrom"
                    echo "Then return here and hit ENTER to continue."
                    read answer
                }
            fi
            ;;
	'iso')
	    set -x
	    umount /mnt/cdrom
            mount -o loop -t iso9660 /dev/${iso_part}/`echo "$iso_file" | sed -e "s/-disc1.iso/-$disc.iso/"` /mnt/cdrom
	    echo 'iso mounted?, hit ENTER'; read x
            set +x
            ;;
        'nfsiso')
	    set -x
            umount /mnt/cdrom
            mount -o loop -t iso9660 /mnt/loop/`echo "$iso_file" | sed -e "s/-disc1.iso/-$disc.iso/"` /mnt/cdrom
            mount
            echo hit ENTER; read x
            set +x
            ;;
	esac
    fi

    if [ ${method} = 'httprpms' ]; then
        # precede every  package with http://...
        # sort -u $rsv/install.$disc | grep -v '^--' | sed -e s,^,http://${HOST}${FILE_PATH},
        # echo these packages are going to be installed, ENTER
        # read x
        echo Installing rpms via http from $distri FC${version} $disc - this may take a while ...

	# Following are 2 different ways to do the install. Only one should be active.
	# 1) Install every single package without looking at dependencies
	cd /httptmp
	grep -v -- '^--' $rsv/install.$disc | while read rpm
	do
	    echo busybox wget -c http://$HOST$FILE_PATH$rpm
	    /bin/busybox wget -c http://$HOST$FILE_PATH$rpm || {
		echo wget failed for http://$HOST$FILE_PATH$rpm | tee -a $i_log
		echo hit ENTER; read x
		continue
	    }
	    echo FC rpm -ivh $skipdocs --force --nodeps $rpm | tee -a $i_log
	    /bin/rpm -ivh $skipdocs --force --nodeps $rpm | tee -a $i_log
	    rm $rpm
	done
	cd -

# 	# 2) Install all packaged and honour dependencies
#       # 
# 	echo FC rpm -ivh $skipdocs --force `sort -u $rsv/install.$disc | grep -v -- '^--' | sed -e s,^,http://${HOST}${FILE_PATH},` | tee -a $i_log
# 	sleep 3
#         /bin/rpm -ivh $skipdocs --force `sort -u $rsv/install.$disc | grep -v '^--' | sed -e s,^,http://${HOST}${FILE_PATH},` 2>&1 | tee -a $i_log


    elif [ ${method} = 'ftprpms' ]; then
        # precede every  package with ftp:/...
        # sort -u $rsv/install.$disc | grep -v '^--' | sed -e s,^,ftp://${LOGIN}${HOST}${PORT}${FILE_PATH},
        # echo these packages are going to be installed, ENTER
        # read x
        echo Installing rpms via ftp from $distri FC${version} $disc - this may take a while ...
	set -x
        /bin/rpm -ivh $skipdocs --force `sort -u $rsv/install.$disc | grep -v '^--' | sed -e s,^,ftp://${HOST}${PORT}/${FILE_PATH}/,` 2>&1 | tee -a $i_log
	set +x
	sleep 3
    else
        cd ${RPM_PATH}
        ct=`sort -u $rsv/install.$disc | grep -v '^--' | wc -l`
        if [ "$ct" -gt '0' ];  then
            echo -n "Installing $ct rpms from $distri FC${version} $disc - "
            if [ "$ct" -gt 20 ];  then
                echo this may take a while ...
            else
                echo this should not last very long ...
            fi
            /bin/rpm -ivh $skipdocs --force `sort -u $rsv/install.$disc | grep -v '^--' ` 2>&1 | tee -a $i_log

## Use this code to install on i486
##	    cd /
##          sort -u $rsv/install.$disc | grep -v '^--' | while read p; do
##		busybox rpm2cpio ${RPM_PATH}/$p | cpio -iduv
##          done
##	    cd -
        fi
        cd
    fi

# fi
done

echo "Finished installing RPM's at `date`" | tee -a $i_log
echo
sleep 3

# Reset filesystem permissions to default.
# During setup, /var/spool/mail doesn't get set to group "mail".

/bin/rpm --setugids filesystem > /dev/null 2>&1

# not used now ## if [ -x $rs/rulerc.sh ]; then
# not used now ##     echo "Executing $rs/rulerc.sh"
# not used now ##     echo hit ENTER
# not used now ##     read x
# not used now ##     $rs/rulerc.sh | tee -a $i_log
# not used now ##     echo Done.
# not used now ## fi

# CD installs.
if [ "$method" = "cdrom" ]; then
    echo "Unmounting and ejecting cdrom..."
    umount /mnt/cdrom
    eject $CDROM_DEV
    echo "Done."
fi

$rs/unmount_installsource.sh

# busybox-rpm installed lots of config- and system-files when
# installing fedora-rpm.
# Afterwards this rpm creates files ending in rpmorig and rpmnew
# due to those existing files - we simlpy/silently remove them all

find / -xdev -type f -name \*\.rpmorig | xargs rm -rf
find / -xdev -type f -name \*\.rpmnew | xargs rm -rf

echo
echo "Install completed: `date`" | tee -a $i_log
echo "See the installation log at: $rs/install.log, Hit ENTER"; read x
