#! /bin/sh
#
#  format_mount.sh

# Find other linux partitions, ignore swap.
# Again, a better way would be useful.

export BOOT_IS_DEVICE

if [ "$method" = "iso" ] || [ "$method" = "rpms" ]; then
    avail_parts=`fdisk -l | grep  Linux | grep -v swap |\
    grep -v ${iso_part} | cut -d / -f 3 | cut -c 1-5`
else
    avail_parts=`fdisk -l | grep  Linux | grep -v swap |\
    cut -d / -f 3 | cut -c 1-5`
fi

echo Available partitions = $avail_parts | tee -a $i_log

# Log the output of fdisk so we have a record for troubleshooting.
echo >> $i_log
echo "############# FDISK OUTPUT ###############" >> $i_log
/sbin/fdisk -l >> $i_log
echo "########### END FDISK OUTPUT #############" >> $i_log
echo >> $i_log

# Explicitly create the '/' partition. The user can create other mount
# points, but we need to be sure we have '/'.
valid=0
ROOT_PART=''
while [ "$valid" -eq "0" ]
do
    # If not defined in the config file ask.

    if [ -z "$ROOT_PART" ]; then
	dialog --inputbox \
"    Which partition shall become your new '/' filesystem.

    Available partitions are: [ `echo $avail_parts` ]
" 12 70 '' 2>/tmp/dialog.ipt
	ROOT_PART=`cat /tmp/dialog.ipt`
    fi

    # In all cases, do a sanity check.
    echo "The selected root partition was <$ROOT_PART>" >> $i_log
    if [ -z "$ROOT_PART" ]; then
	dialog --msgbox '
    You did not choose a root partition!
' 12 70
	continue
    fi

    if [ "/dev/$ROOT_PART" = "$INSTALL_DEV" ]; then
	dialog --msgbox "
    You selected the entire device $ROOT_PART
    You should select a single partition instead.
" 12 70
	continue
    fi

    if [ "$ROOT_PART" = "/dev/" ]; then
	dialog --msgbox '
    Hrmm, I ended up with /dev/ as your root partition.
    That s not good.
' 12 70
	continue
    fi

    echo $avail_parts | grep -q $ROOT_PART 2> /dev/null

    if [ $? -ne 0 ] ; then
	dialog --msgbox "
    Partition [ $ROOT_PART ] isn't a valid entry
    within available partitions [ $avail_parts ].
" 12 70
	valid=0
	# Avoid a loop due to a bad config file define.
	ROOT_PART=
    else
	valid=1
	ROOT_DEV=/dev/$ROOT_PART
	export ROOT_PART ROOT_DEV
	echo ROOT_DEV=$ROOT_DEV >> $i_log
    fi
    abort=0
done

# unmount /newroot and all filesystems beneath
cat /proc/mounts | grep /newroot/mnt | awk '{print $2}' | sort -r | while read fs; do
    umount $fs
done
cat /proc/mounts | grep /newroot | awk '{print $2}' | sort -r | while read fs; do
    umount $fs
done

# Format the root file system.
if [ -z "$SKIP_FORMAT_ROOT" ]; then
    dialog --defaultno --colors --yesno "
    It is suggested that you format the '/' filesystem at
    device '${ROOT_DEV}'.
\Z1    
                     *************
                     * Attention *
                     *************

    But -!- formatting erases the contents of this partition,
    no way to get it back later.
\Zn
    Format [ ${ROOT_DEV} ] type <$fstype> now ?
" 18 70
[ $? -eq 0 ] && answer=yes || answer=no

    if [ "$answer" = 'yes' ]; then
	echo "Creating root file system."
#	umount ${ROOT_DEV} 2>/dev/null
	mke2fs ${fsopts} ${ROOT_DEV} || {
	    echo "Failed to create file system, exiting. Hit ENTER" | tee -a $i_log
	    read x
# 	    echo "Turning off swap."
# 	    for device in $SWAP_DEV
# 	    do
# 		swapoff "$device"
# 		break
# 	    done
        }
	echo 'Done.'
#	sleep 3
    fi
else
    if [ "$SKIP_FORMAT_ROOT" -eq "0" ]; then
	echo "Creating root file system."
#	umount ${ROOT_DEV} 2>/dev/null
	mke2fs ${fsopts} ${ROOT_DEV} || {
	    echo "Failed to create file system, exiting. Hit ENTER" | tee -a $i_log
	    read x
# 	    echo "Turning off swap."
# 	    for device in $SWAP_DEV
# 	    do
# 		swapoff "$device"
# 		break
# 	    done
	}
	echo "Done."
    fi
fi

# Mount the root filesystem.
echo "Mounting the root partition $ROOT_DEV on '/newroot'." | tee -a $i_log
# mount | grep /newroot || mount "$ROOT_DEV" /newroot 2>&1 || {
mount "$ROOT_DEV" /newroot || {
    echo 'Failed to mount the root filesystem, exiting.' | tee -a $i_log
    echo 'Hit ENTER'; read x
#   echo "Turning off swap."
#   for device in $SWAP_DEV
#   do
#     swapoff $device
#   done
}
sleep 3

# Remove the root device from the list of available devices.
avail_parts=`echo $avail_parts | sed 's/'$ROOT_PART'//'`

#Check for another available partition.
if [ -n "$avail_parts" ] ; then
    dialog --msgbox "
    The following partitions are also available for use:

    [ `echo $avail_parts` ]

    You may select mount points for each. Those not selected
    will not be formatted or mounted during installation.
" 12 70
    
    for part in $avail_parts
    do
	dialog --inputbox \
"    Enter a mount point for [ /dev/$part ]
    For example: boot, var, usr, home.

    If you dont want to format and mount this partition do not
    input anything.  Just hit ENTER.
" 12 70	'' 2>/tmp/dialog.ipt
	mount_point=`cat /tmp/dialog.ipt`
	[ "$mount_point" = 'boot' ] && { BOOT_IS_DEVICE=yes; }
	if [ -n "$mount_point" ] ; then
	    MOUNTS="$MOUNTS $mount_point"
	    echo "/dev/$part will be mounted as $mount_point." | tee -a $i_log
	    dialog --defaultno --colors --yesno "
    It is suggested that you format the '$mount_point' filesystem at
    device '/dev/$part'.
\Z1    
                     *************
                     * Attention *
                     *************

    But -!- formatting erases the contents of this partition,
    no way to get it back later.
\Zn
    Format [ /dev/$part ] type <$fstype> now ?
" 18 70
	    [ $? -eq 0 ] && answer=yes || answer=no
	    if [ "$answer" = 'yes' ]; then
		echo "Creating $mount_point filesystem."
#		umount /newroot/$mount_point 2>/dev/null
		mke2fs ${fsopts} /dev/$part > /dev/null 2>&1 || {
		    echo "Failed to create file system on /dev/$part, exiting. Hit ENTER" | tee -a $i_log
		    read x
# 		    sleep 5
# 		    echo "Turning off swap."
# 		    for device in $SWAP_DEV
# 		    do
# 			swapoff $device
# 		    done
# 		    umount $ROOT_DEV
# 		    umount -a
		    break
		}
	    echo "Done."
	    sleep 3
        fi
        echo "Mounting /dev/$part on '/newroot/$mount_point'."
        mkdir -p /newroot/$mount_point
        mount /dev/$part /newroot/$mount_point > /dev/null 2>&1 || {
	    echo "Failed to mount the $mount_point filesystem. Hit ENTER" | tee -a $i_log
	    read x
#           sleep 5
# 	    echo "Turning off swap."
# 	    for device in $SWAP_DEV
# 	    do
# 		swapoff $device
# 	    done
# 	    umount $ROOT_DEV
# 	    umount -a
	    break
        }
        echo 'Done.'
        echo "/dev/$part      $mount_point          $fstype    defaults      1 2" >> fstab
        avail_parts=`echo $avail_parts | sed 's/'$part'//'`
    fi
    done
    echo Mount points=$MOUNTS >> $i_log
fi
export MOUNTS

echo Preparing some files and directories in /newroot
sleep 3

. /scripts/prepare_newroot.sh

sleep 3