#! /bin/sh
#
#  grub_install.sh

# set -x

echo Preparing to install GRUB
# . /scripts/slinky.config

# Get the kernel and initrd names
kernel_name=`ls /boot/ | grep vmlinuz-`
# kernel_name_FC3=vmlinuz-2.6.9-1.667                 # FC3
# kernel_name_FC4=vmlinuz-2.6.11-1.1369_FC4           # FC4
# kernel_name_FC5=vmlinuz-2.6.15-1.1826.2.10_FC5      # FC5
kernel_version=`echo $kernel_name | cut -d- -f2-`
initrd_name=`ls /boot/ | grep initrd-`
# initrd_name_FC3=initrd-2.6.9-1.667.img              # FC3
# initrd_name_FC4=initrd-2.6.11-1.1369_FC4.img        # FC4
# initrd_name_FC5=initrd-2.6.15-1.1826.2.10_FC5.img   # FC4

# Create grub.conf.  This should be usesd as the default, because grub.rpm
# is on the first FC-CDROM, lilo.rpm is not.
# Device numbers are not currently handled at all. (0,1) for example.

# Create the directory for grub
[ ! -d /boot/grub ] && mkdir -p /boot/grub

GRUB=/boot/grub/grub.conf
# when /boot is a partition, then don't prepend /boot to the names
bootprefix=/boot
[ "$BOOT_IS_DEVICE" = 'yes' ] && bootprefix=''

cat >$GRUB <<EOF
# File generated by the RULE Slinky installer $version_id.
# You do not have to rerun grub after making changes to this file
# NOTICE:  If you have a /boot partition, all kernel and
#          initrd paths are relative to the /boot-Partition and
#          so the part '/boot' is not required in filenames.
#          But if /boot is stored in the root-partition itself all
#          filenames need to start with '/boot'...
#
# boot=$INSTALL_DEV
# boot=(hd0,0)
default=saved
timeout=60
# splashimage=(hd0,1)/grub/splash.xpm.gz
title Fedora FC$version (kernel $kernel_version + initrd)
kernel $bootprefix/$kernel_name root=$ROOT_DEV ro
initrd $bootprefix/$initrd_name
EOF

dialog --yesno "
    Do you want to add the installation kernel from SLINKY
    to the boot options of your new system?  This could be
    usefull if you have too less memory to boot the regular
    kernel of FC${version} or if your processor is real i386.

    Insert the SLINKY boot-floppy or select NO.
" 12 70
[ $? -eq 0 ] && answer=yes || answer=no
if [ "$answer" = 'yes' ]; then
    while :; do
	# echo Insert SLINKY boot-floppy, hit ENTER; read x
	mount -t msdos /dev/fd0 /mnt/floppy && break
    done

    cp /mnt/floppy/vmlinuz /boot/vmlinuz-${ik_version} || {
	echo copying /mnt/floppy/vmlinuz to /boot/vmlinuz-${ik_version} failed, hit ENTER; read x
    }
    umount /mnt/floppy

    # add the small Kernel from the SLINKY boot-disk
    cat >>$GRUB <<EOF
title Small Kernel ${ik_version} from SLINKY boot-floppy ${version_id}
kernel $bootprefix/vmlinuz-${ik_version} root=$ROOT_DEV ro
EOF
fi


dialog --defaultno --yesno "
    Shall GRUB be installed in the MBR of $INSTALL_DEV ?

    This will overwrite the masterboot record (MBR) of $INSTALL_DEV.
    If you have installed also other operating systems, they
    might not boot any more.  (Thou it is possible to configure
    GRUB later in a way to also boot these systems).

    If you are unshure whether to overwrite the MBR or not, select
    'NO' here.  You can boot your newly installed system temporary
    even with the Slinky installation floppy when you enter:

    boot: 'linux root=/dev/$ROOT_PART ro' at the lilo prompt. 
" 18 70
[ $? -eq 0 ] && answer=yes || answer=no
    
if [ "$answer" = "yes" ]; then
    echo grub-install "$INSTALL_DEV" >>$i_log
    grub-install $INSTALL_DEV || {
        echo "grub-install $INSTALL_DEV didn't finish properly!"
	echo "You should fix that before continuing."
	echo "If you want to try to fix GRUB, enter"
	echo "Alt-F2 for a new shell, edit $GRUB"
	echo "and rerun: grub-install $INSTALL_DEV"
	echo "You can then return here (Alt-F1)"
	echo "and hit ENTER to continue."
	echo -n "ENTER to continue. :"
	read answer
    }
else
   echo "GRUB installation skipped by user." | tee -a $i_log
   sleep 3
fi
