#! /bin/sh
#
#  select_instdev.sh

# Prompt for the install device, and do some sanity checking.
# Attempt to list all available drives, partition those requested.

PART_DEV=
avail_devices=`/sbin/fdisk -l | grep Disk | cut -d " " -f 2 | cut -d "/" -f 3 | cut -d : -f 1`
DISKS=$avail_devices
echo Available devices = $avail_devices | tee -a $i_log
have_device=0
multiple_disks=0
another_device=1
while [ "$have_device" -ne "1" ] || [ "$another_device" -eq "1" ]
do
    # Reset another_device, or we'll never break out of the loop.
    another_device=0

    # If not defined in the config file, ask.
    if [ -z "$device" ]; then
	dialog --inputbox \
"    To which device would you like to install RULE?
    There is no default value, please enter a valid device
    from the list below.

    Available devices are: [ `echo $avail_devices` ]
" 13 70 '' 2>/tmp/dialog.ipt
        [ "$?" = '1' ] && return
	device=`cat /tmp/dialog.ipt`
    fi

    # There is no default. Make sure we don't have an empty string.

    if [ -z "$device" ] ; then
	dialog --msgbox \
"    You didn't enter a device name!
" 12 70
	continue
    else

        # Catch typos. Make sure it is a valid device.
    
        echo $avail_devices | grep -q $device > /dev/null 2>&1
        if [ $? -ne 0 ]; then
            echo "<${device}> doesn't appear to be a valid hard drive device." | tee -a $i_log
            echo "Unable to locate <${device}>" | tee -a $i_log
            have_device=0
            device=
	    sleep 3
        else
            PART_DEV="$PART_DEV /dev/$device"
	    echo "Selected [ /dev/${device} ] for installing." | tee -a $i_log
	    dialog --msgbox "
    You selected [ /dev/$device ] for installing.
" 12 70
            have_device=1
            avail_devices=`echo ${avail_devices} | sed 's/'$device'//'`
            device=
        fi
    
        # If the config file doesn't tell us to use another device...
    
        if [ -z "${use_additional_device}" ];then
    
            # Check to see if more devices are available, and prompt for details.
    
            if [ -n "${avail_devices}" ]; then
		echo
		answer=
		while [ "$answer" != 'yes' ] && [ "$answer" != 'NO' ]; do
		    echo -n "Would you like to select an additional device? [ yes / NO ]: "
		    read answer
		    [ "$answer" = '' ] && answer='NO'
		done
		if [ "$answer" = "yes" ]; then
		    another_device=1
		    multiple_disks=1
		fi
            fi
    
            # If the user selected multiple devices, and selected a second device...
    
        else
            another_device=1
            multiple_disks=1
            device="${device2}"
            use_additional_device=
        fi
    fi
done

# If we have more than one drive, we need to know where to install grub.
# We don't want to just assume, and overwrite the MBR on a disk.
if [ "$multiple_disks" -eq "1" ]; then
    valid=0
    while [ $valid -eq 0 ]
    do
    echo
    # If not defined in the config file ask.
    if [ -z "${lilo_dev}" ]; then
        echo "You have selected multiple drives for this install."
        echo "To install the boot loader, I need to know which drive is"
        echo "bootable. At the end of the installation, you will have"
        echo "the option of installing GRUB on this drive."
        echo
        echo -n "Which drive shall I consider bootable? [ "$DISKS" ] :"
        read lilo_dev
        echo
    fi
    # Prevent an empty string
    if [ -z "$lilo_dev" ] ; then
        echo "You didn't enter a drive name!"
        echo
        # Back to the start of the loop.
        continue
    else

        echo $DISKS | grep -q $lilo_dev > /dev/null 2>&1
        if [ $? -eq 0 ]; then
        valid=1
        INSTALL_DEV="/dev/$lilo_dev"
        # reset lilo_dev to avoid a loop with a bad config file define.
        else
        lilo_dev=
        fi
    fi
    done
else
    INSTALL_DEV=`echo $PART_DEV`
fi

export PART_DEV INSTALL_DEV
echo PART_DEV=$PART_DEV >> $i_log
echo INSTALL_DEV=$INSTALL_DEV >> $i_log

# If we are here, we should have a valid device name.
# It may not exist, and may not be a hard drive, however.
## dialog --msgbox "
##     You selected [ `echo $PART_DEV` ] for partitioning.
## " 10 70
if [ -n "$CDROM_DEV" ]; then
    echo $PART_DEV | grep -q $CDROM_DEV
    if [ $? -eq 0 ]; then
	echo "I found, you have selected your cdrom device <$CDROM_DEV> for partitioning."
	echo "If your cdrom <$CDROM_DEV> was detected incorrectly, this might be OK."
	answer=
	while [ "$answer" != 'yes' &&  "$answer" != 'NO' ]; do
	    echo -n "Are you sure? [ yes / NO ]: "
	    read answer
	    [ "$answer" = '' ] && answer='NO'
	done
    if [ "$answer" != "yes" ]; then
        echo "Exiting in complete confusion, at the users request."
        exit
    fi
    echo $PART_DEV matched the CDROM entry. >> $i_log
    fi
fi
