#!/bin/sh

# create SLINKY boot-floppy

# set -x

. version.h
# FD=/dev/fd0u1722
# FN="b 2 60"
# BC=1722
FD=/dev/fd0
FN="b 2 0"
BC=1440

image=${version}-disk1.img

echo
echo "Creating boot disk ${image}."

rm rootfs*
echo "Creating new rootfs"
dd if=/dev/zero of=rootfs bs=1k count=2048 || {
    echo "Error while creating filesystem, exiting."
    exit
}

mkfs.ext2 -F -m 0 -N 700 -b 1024 rootfs || {
    echo "Error while making ext2 filesystem, exiting."
    exit
}

echo "Mounting rootfs on the loop device."
rm -rf loop
mkdir loop
mount -o loop rootfs loop/ || {
    echo "Error mounting filesystem, exiting."
    exit
}

trap "echo unmounting bootdisk1 from loop; umount `pwd -P`/${image}" 0

mount

rm -Rf loop/lost+found
echo "Copying filesystem."
# cp -a filesystem/* loop || {
#     echo "Error copying filesystem, exiting."
#     exit
# }

cd filesystem
cp -a . ../loop
find ../loop -name CVS -exec rm -rf {} \;
# find . -print | grep -v CVS | grep -v /lib/modules/${ik_version} | cpio -pvdm ../loop
cd -

# find loop -depth -print | xargs touch -t "200601010000"
# find loop -type l -print | xargs touch -t "200601010000"
echo that\'s loop now:
ls -l loop
# find loop -ls >/tmp/rootfs_contents.list
df -k
echo hit ENTER
read x

echo "Unmounting loop filesystem."
umount loop || {
    echo "Error unmounting loop filesystem, exiting."
    exit
}
echo "Gzipping root file system."
gzip -9 rootfs

echo "Creating ${image}"
dd if=/dev/zero of=${image} bs=1k count=$BC

echo "Formatting ${image}."
mkdosfs -r 16 -C ${image} $BC || {
    echo "Error formatting the floppy image, exiting."
    exit
}

echo "Running syslinux."
syslinux ${image} || {
    echo "Error running syslinux, exiting."
    exit
}

echo press ENTER; read x

echo "Mounting ${image} on the loop device."
mount -o loop -t msdos ${image} loop || {
    echo "Error mounting filesystem, exiting."
    exit
}

echo "Copying files."
cp base_files/syslinux.cfg loop
sed -e "s/IK_VERSION/${ik_version}/g" -e "s/FC_VERSION/${fc_version}/g" -e "s/VERSION/${version}/g" base_files/boot.msg > loop/boot.msg
sed -e "s/IK_VERSION/${ik_version}/g" -e "s/FC_VERSION/${fc_version}/g" -e "s/VERSION/${version}/g" base_files/boot2.msg > loop/boot2.msg

cp base_files/col9.msg loop
# cp base_files/col0.msg loop
# cp base_files/rule.lss loop
# cp base_files/sample.msg loop
cp base_files/rulelogo.lss loop
# cp base_files/tuxsmall.lss loop

echo "Copying rootfs.gz."
cp rootfs.gz loop

echo "Copying the kernel."
cp base_files/vmlinuz loop/

du -sk loop/*
df -k loop
ls -l rootfs.gz

echo
echo If there is no space left in the slinky-img \(column Available = 0\)
echo the installation will not work. Repeat this script, the size of
echo rootfs.gz might surprisingly change slightly.
echo press ENTER; read x

echo "Unmounting loop filesystem."
umount loop || {
    echo "Error unmounting loop filesystem, exiting."
    exit
}

echo "Moving ${image} to slinky directory."
mkdir -p slinky-images/${version}
mv ${image} slinky-images/${version} || {
    echo "Error moving ${image}."
    exit
}
rm -f rootfs.gz
# mount

[ -b $FD ] || mknod $FD $FN || { echo mknod $FD $FN failed - press ENTER; read x; }

echo creating a floppy with: dd if=slinky-images/${version}/${image} of=$FD bs=512
dd if=slinky-images/${version}/${image} of=$FD bs=512
echo
echo "Done."
exit

