#!/bin/sh

# create an image with modules for SLINKY
# All Modules are located under /lib/modules/${ik_version}
# Copy them to a ext2-image. This image can be mounted later when
# installing with slinky under /lib/modules/${ik_version}.

# set -x

. version.h

image=${version}-modules.img

trap "echo unmounting modulesdisk from loop; umount `pwd`/${image}" 0

echo
echo "Creating modules image ${image}."

rm ${image}
dd if=/dev/zero of=${image} bs=1024 count=8000 || {
    echo "Error while creating ${image}, exiting."
    exit
}

mkfs.ext2 -F -m 0 -N 300 -b 1024 ${image} || {
    echo "Error while making ext2 filesystem on ${image}, exiting."
    exit
}

echo "Mounting ${image} on the loop device."
mount -o loop ${image} loop/ || {
    echo "Error mounting filesystem, exiting."
    exit
}

rm -rf loop/lost+found
echo "Copying modules."
cp -a /lib/modules/${ik_version} loop || {
    echo "Error copying filesystem, exiting."
    exit
}

echo "Unmounting loop filesystem."
umount loop || {
    echo "Error unmounting loop filesystem, exiting."
    exit
}

bzip2 ${image}

echo "Moving ${image} to slinky directory."
[ ! -d slinky-images/${version} ] && mkdir -p slinky-images/${version}
mv ${image}.bz2 slinky-images/${version} || {
    echo "Error moving ${image}.bz2."
    exit
}

echo
echo "Done."
exit

